# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .date_range import DateRange
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DynamicDateRange(DateRange):
    """
    The saved dynamic date range (Required when staticDateRange is missing).
    """

    #: A constant which can be used with the dynamic_date_range_type property of a DynamicDateRange.
    #: This constant has a value of "LAST_7_DAYS"
    DYNAMIC_DATE_RANGE_TYPE_LAST_7_DAYS = "LAST_7_DAYS"

    #: A constant which can be used with the dynamic_date_range_type property of a DynamicDateRange.
    #: This constant has a value of "LAST_CALENDAR_WEEK"
    DYNAMIC_DATE_RANGE_TYPE_LAST_CALENDAR_WEEK = "LAST_CALENDAR_WEEK"

    #: A constant which can be used with the dynamic_date_range_type property of a DynamicDateRange.
    #: This constant has a value of "LAST_CALENDAR_MONTH"
    DYNAMIC_DATE_RANGE_TYPE_LAST_CALENDAR_MONTH = "LAST_CALENDAR_MONTH"

    #: A constant which can be used with the dynamic_date_range_type property of a DynamicDateRange.
    #: This constant has a value of "LAST_30_DAYS"
    DYNAMIC_DATE_RANGE_TYPE_LAST_30_DAYS = "LAST_30_DAYS"

    #: A constant which can be used with the dynamic_date_range_type property of a DynamicDateRange.
    #: This constant has a value of "MONTH_TO_DATE"
    DYNAMIC_DATE_RANGE_TYPE_MONTH_TO_DATE = "MONTH_TO_DATE"

    #: A constant which can be used with the dynamic_date_range_type property of a DynamicDateRange.
    #: This constant has a value of "LAST_YEAR"
    DYNAMIC_DATE_RANGE_TYPE_LAST_YEAR = "LAST_YEAR"

    #: A constant which can be used with the dynamic_date_range_type property of a DynamicDateRange.
    #: This constant has a value of "YEAR_TODATE"
    DYNAMIC_DATE_RANGE_TYPE_YEAR_TODATE = "YEAR_TODATE"

    def __init__(self, **kwargs):
        """
        Initializes a new DynamicDateRange object with values from keyword arguments. The default value of the :py:attr:`~oci.usage_api.models.DynamicDateRange.date_range_type` attribute
        of this class is ``DYNAMIC`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param date_range_type:
            The value to assign to the date_range_type property of this DynamicDateRange.
            Allowed values for this property are: "STATIC", "DYNAMIC", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type date_range_type: str

        :param dynamic_date_range_type:
            The value to assign to the dynamic_date_range_type property of this DynamicDateRange.
            Allowed values for this property are: "LAST_7_DAYS", "LAST_CALENDAR_WEEK", "LAST_CALENDAR_MONTH", "LAST_30_DAYS", "MONTH_TO_DATE", "LAST_YEAR", "YEAR_TODATE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type dynamic_date_range_type: str

        """
        self.swagger_types = {
            'date_range_type': 'str',
            'dynamic_date_range_type': 'str'
        }

        self.attribute_map = {
            'date_range_type': 'dateRangeType',
            'dynamic_date_range_type': 'dynamicDateRangeType'
        }

        self._date_range_type = None
        self._dynamic_date_range_type = None
        self._date_range_type = 'DYNAMIC'

    @property
    def dynamic_date_range_type(self):
        """
        **[Required]** Gets the dynamic_date_range_type of this DynamicDateRange.
        Allowed values for this property are: "LAST_7_DAYS", "LAST_CALENDAR_WEEK", "LAST_CALENDAR_MONTH", "LAST_30_DAYS", "MONTH_TO_DATE", "LAST_YEAR", "YEAR_TODATE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The dynamic_date_range_type of this DynamicDateRange.
        :rtype: str
        """
        return self._dynamic_date_range_type

    @dynamic_date_range_type.setter
    def dynamic_date_range_type(self, dynamic_date_range_type):
        """
        Sets the dynamic_date_range_type of this DynamicDateRange.

        :param dynamic_date_range_type: The dynamic_date_range_type of this DynamicDateRange.
        :type: str
        """
        allowed_values = ["LAST_7_DAYS", "LAST_CALENDAR_WEEK", "LAST_CALENDAR_MONTH", "LAST_30_DAYS", "MONTH_TO_DATE", "LAST_YEAR", "YEAR_TODATE"]
        if not value_allowed_none_or_none_sentinel(dynamic_date_range_type, allowed_values):
            dynamic_date_range_type = 'UNKNOWN_ENUM_VALUE'
        self._dynamic_date_range_type = dynamic_date_range_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ConnectivityValidation(object):
    """
    The information about connectivity validation results
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ConnectivityValidation object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param total_message_count:
            The value to assign to the total_message_count property of this ConnectivityValidation.
        :type total_message_count: int

        :param error_message_count:
            The value to assign to the error_message_count property of this ConnectivityValidation.
        :type error_message_count: int

        :param warn_message_count:
            The value to assign to the warn_message_count property of this ConnectivityValidation.
        :type warn_message_count: int

        :param info_message_count:
            The value to assign to the info_message_count property of this ConnectivityValidation.
        :type info_message_count: int

        :param validation_messages:
            The value to assign to the validation_messages property of this ConnectivityValidation.
        :type validation_messages: dict(str, list[ValidationMessage])

        """
        self.swagger_types = {
            'total_message_count': 'int',
            'error_message_count': 'int',
            'warn_message_count': 'int',
            'info_message_count': 'int',
            'validation_messages': 'dict(str, list[ValidationMessage])'
        }

        self.attribute_map = {
            'total_message_count': 'totalMessageCount',
            'error_message_count': 'errorMessageCount',
            'warn_message_count': 'warnMessageCount',
            'info_message_count': 'infoMessageCount',
            'validation_messages': 'validationMessages'
        }

        self._total_message_count = None
        self._error_message_count = None
        self._warn_message_count = None
        self._info_message_count = None
        self._validation_messages = None

    @property
    def total_message_count(self):
        """
        **[Required]** Gets the total_message_count of this ConnectivityValidation.
        Total number of validation messages


        :return: The total_message_count of this ConnectivityValidation.
        :rtype: int
        """
        return self._total_message_count

    @total_message_count.setter
    def total_message_count(self, total_message_count):
        """
        Sets the total_message_count of this ConnectivityValidation.
        Total number of validation messages


        :param total_message_count: The total_message_count of this ConnectivityValidation.
        :type: int
        """
        self._total_message_count = total_message_count

    @property
    def error_message_count(self):
        """
        Gets the error_message_count of this ConnectivityValidation.
        Total number of validation error messages


        :return: The error_message_count of this ConnectivityValidation.
        :rtype: int
        """
        return self._error_message_count

    @error_message_count.setter
    def error_message_count(self, error_message_count):
        """
        Sets the error_message_count of this ConnectivityValidation.
        Total number of validation error messages


        :param error_message_count: The error_message_count of this ConnectivityValidation.
        :type: int
        """
        self._error_message_count = error_message_count

    @property
    def warn_message_count(self):
        """
        Gets the warn_message_count of this ConnectivityValidation.
        Total number of validation warning messages


        :return: The warn_message_count of this ConnectivityValidation.
        :rtype: int
        """
        return self._warn_message_count

    @warn_message_count.setter
    def warn_message_count(self, warn_message_count):
        """
        Sets the warn_message_count of this ConnectivityValidation.
        Total number of validation warning messages


        :param warn_message_count: The warn_message_count of this ConnectivityValidation.
        :type: int
        """
        self._warn_message_count = warn_message_count

    @property
    def info_message_count(self):
        """
        Gets the info_message_count of this ConnectivityValidation.
        Total number of validation information messages


        :return: The info_message_count of this ConnectivityValidation.
        :rtype: int
        """
        return self._info_message_count

    @info_message_count.setter
    def info_message_count(self, info_message_count):
        """
        Sets the info_message_count of this ConnectivityValidation.
        Total number of validation information messages


        :param info_message_count: The info_message_count of this ConnectivityValidation.
        :type: int
        """
        self._info_message_count = info_message_count

    @property
    def validation_messages(self):
        """
        Gets the validation_messages of this ConnectivityValidation.
        Detailed information of the connectivity validation.


        :return: The validation_messages of this ConnectivityValidation.
        :rtype: dict(str, list[ValidationMessage])
        """
        return self._validation_messages

    @validation_messages.setter
    def validation_messages(self, validation_messages):
        """
        Sets the validation_messages of this ConnectivityValidation.
        Detailed information of the connectivity validation.


        :param validation_messages: The validation_messages of this ConnectivityValidation.
        :type: dict(str, list[ValidationMessage])
        """
        self._validation_messages = validation_messages

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .format_entry import FormatEntry
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DeterministicEncryptionFormatEntry(FormatEntry):
    """
    The Deterministic Encryption masking format encrypts column data using a cryptographic
    key and Advanced Encryption Standard (AES 128). It can be used to encrypt character and
    number columns. It can encrypt ASCII data without any input (except seed value), but it
    needs a regular expression to encrypt non-ASCII data.

    Deterministic Encryption is a format-preserving, deterministic and reversible masking
    format, which requires a seed value while submitting a masking work request. Passing
    the same seed value when masking multiple times or masking different databases ensures
    that the data is masked deterministically. To learn more, check Deterministic Encryption
    in the Data Safe documentation.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DeterministicEncryptionFormatEntry object with values from keyword arguments. The default value of the :py:attr:`~oci.data_safe.models.DeterministicEncryptionFormatEntry.type` attribute
        of this class is ``DETERMINISTIC_ENCRYPTION`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this DeterministicEncryptionFormatEntry.
            Allowed values for this property are: "DELETE_ROWS", "DETERMINISTIC_SUBSTITUTION", "DETERMINISTIC_ENCRYPTION", "DETERMINISTIC_ENCRYPTION_DATE", "FIXED_NUMBER", "FIXED_STRING", "LIBRARY_MASKING_FORMAT", "NULL_VALUE", "POST_PROCESSING_FUNCTION", "PRESERVE_ORIGINAL_DATA", "RANDOM_DATE", "RANDOM_DECIMAL_NUMBER", "RANDOM_DIGITS", "RANDOM_LIST", "RANDOM_NUMBER", "RANDOM_STRING", "RANDOM_SUBSTITUTION", "REGULAR_EXPRESSION", "SHUFFLE", "SQL_EXPRESSION", "SUBSTRING", "TRUNCATE_TABLE", "USER_DEFINED_FUNCTION"
        :type type: str

        :param description:
            The value to assign to the description property of this DeterministicEncryptionFormatEntry.
        :type description: str

        :param regular_expression:
            The value to assign to the regular_expression property of this DeterministicEncryptionFormatEntry.
        :type regular_expression: str

        """
        self.swagger_types = {
            'type': 'str',
            'description': 'str',
            'regular_expression': 'str'
        }

        self.attribute_map = {
            'type': 'type',
            'description': 'description',
            'regular_expression': 'regularExpression'
        }

        self._type = None
        self._description = None
        self._regular_expression = None
        self._type = 'DETERMINISTIC_ENCRYPTION'

    @property
    def regular_expression(self):
        """
        Gets the regular_expression of this DeterministicEncryptionFormatEntry.
        The regular expression to be used for masking. For data with characters in the
        ASCII character set, providing a regular expression is optional. However, it
        is required if the data contains multi-byte characters. If not provided, an
        error is returned when a multi-byte character is found.

        In the case of ASCII characters, if a regular expression is not provided,
        Deterministic Encryption can encrypt variable-length column values while
        preserving their original format.

        If a regular expression is provided, the column values in all the rows must match
        the regular expression. Deterministic Encryption supports a subset of the regular
        expression language. It supports encryption of fixed-length strings, and does not
        support * or + syntax of regular expressions. The encrypted values also match the
        regular expression, which helps to ensure that the original format is preserved.
        If an original value does not match the regular expression, Deterministic Encryption
        might not produce a one-to-one mapping. All non-confirming values are mapped to a
        single encrypted value, thereby producing a many-to-one mapping.


        :return: The regular_expression of this DeterministicEncryptionFormatEntry.
        :rtype: str
        """
        return self._regular_expression

    @regular_expression.setter
    def regular_expression(self, regular_expression):
        """
        Sets the regular_expression of this DeterministicEncryptionFormatEntry.
        The regular expression to be used for masking. For data with characters in the
        ASCII character set, providing a regular expression is optional. However, it
        is required if the data contains multi-byte characters. If not provided, an
        error is returned when a multi-byte character is found.

        In the case of ASCII characters, if a regular expression is not provided,
        Deterministic Encryption can encrypt variable-length column values while
        preserving their original format.

        If a regular expression is provided, the column values in all the rows must match
        the regular expression. Deterministic Encryption supports a subset of the regular
        expression language. It supports encryption of fixed-length strings, and does not
        support * or + syntax of regular expressions. The encrypted values also match the
        regular expression, which helps to ensure that the original format is preserved.
        If an original value does not match the regular expression, Deterministic Encryption
        might not produce a one-to-one mapping. All non-confirming values are mapped to a
        single encrypted value, thereby producing a many-to-one mapping.


        :param regular_expression: The regular_expression of this DeterministicEncryptionFormatEntry.
        :type: str
        """
        self._regular_expression = regular_expression

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DbSystemStoragePerformanceSummary(object):
    """
    Representation of storage performance summary per shapeType .
    """

    #: A constant which can be used with the shape_type property of a DbSystemStoragePerformanceSummary.
    #: This constant has a value of "AMD"
    SHAPE_TYPE_AMD = "AMD"

    #: A constant which can be used with the shape_type property of a DbSystemStoragePerformanceSummary.
    #: This constant has a value of "INTEL"
    SHAPE_TYPE_INTEL = "INTEL"

    def __init__(self, **kwargs):
        """
        Initializes a new DbSystemStoragePerformanceSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param shape_type:
            The value to assign to the shape_type property of this DbSystemStoragePerformanceSummary.
            Allowed values for this property are: "AMD", "INTEL", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type shape_type: str

        :param data_storage_performance_list:
            The value to assign to the data_storage_performance_list property of this DbSystemStoragePerformanceSummary.
        :type data_storage_performance_list: list[oci.database.models.StoragePerformanceDetails]

        :param reco_storage_performance_list:
            The value to assign to the reco_storage_performance_list property of this DbSystemStoragePerformanceSummary.
        :type reco_storage_performance_list: list[oci.database.models.StoragePerformanceDetails]

        """
        self.swagger_types = {
            'shape_type': 'str',
            'data_storage_performance_list': 'list[StoragePerformanceDetails]',
            'reco_storage_performance_list': 'list[StoragePerformanceDetails]'
        }

        self.attribute_map = {
            'shape_type': 'shapeType',
            'data_storage_performance_list': 'dataStoragePerformanceList',
            'reco_storage_performance_list': 'recoStoragePerformanceList'
        }

        self._shape_type = None
        self._data_storage_performance_list = None
        self._reco_storage_performance_list = None

    @property
    def shape_type(self):
        """
        **[Required]** Gets the shape_type of this DbSystemStoragePerformanceSummary.
        ShapeType of the DbSystems,INTEL or AMD

        Allowed values for this property are: "AMD", "INTEL", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The shape_type of this DbSystemStoragePerformanceSummary.
        :rtype: str
        """
        return self._shape_type

    @shape_type.setter
    def shape_type(self, shape_type):
        """
        Sets the shape_type of this DbSystemStoragePerformanceSummary.
        ShapeType of the DbSystems,INTEL or AMD


        :param shape_type: The shape_type of this DbSystemStoragePerformanceSummary.
        :type: str
        """
        allowed_values = ["AMD", "INTEL"]
        if not value_allowed_none_or_none_sentinel(shape_type, allowed_values):
            shape_type = 'UNKNOWN_ENUM_VALUE'
        self._shape_type = shape_type

    @property
    def data_storage_performance_list(self):
        """
        **[Required]** Gets the data_storage_performance_list of this DbSystemStoragePerformanceSummary.
        List of storage performance for the DATA disks


        :return: The data_storage_performance_list of this DbSystemStoragePerformanceSummary.
        :rtype: list[oci.database.models.StoragePerformanceDetails]
        """
        return self._data_storage_performance_list

    @data_storage_performance_list.setter
    def data_storage_performance_list(self, data_storage_performance_list):
        """
        Sets the data_storage_performance_list of this DbSystemStoragePerformanceSummary.
        List of storage performance for the DATA disks


        :param data_storage_performance_list: The data_storage_performance_list of this DbSystemStoragePerformanceSummary.
        :type: list[oci.database.models.StoragePerformanceDetails]
        """
        self._data_storage_performance_list = data_storage_performance_list

    @property
    def reco_storage_performance_list(self):
        """
        **[Required]** Gets the reco_storage_performance_list of this DbSystemStoragePerformanceSummary.
        List of storage performance for the RECO disks


        :return: The reco_storage_performance_list of this DbSystemStoragePerformanceSummary.
        :rtype: list[oci.database.models.StoragePerformanceDetails]
        """
        return self._reco_storage_performance_list

    @reco_storage_performance_list.setter
    def reco_storage_performance_list(self, reco_storage_performance_list):
        """
        Sets the reco_storage_performance_list of this DbSystemStoragePerformanceSummary.
        List of storage performance for the RECO disks


        :param reco_storage_performance_list: The reco_storage_performance_list of this DbSystemStoragePerformanceSummary.
        :type: list[oci.database.models.StoragePerformanceDetails]
        """
        self._reco_storage_performance_list = reco_storage_performance_list

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ReportDefinitionSummary(object):
    """
    Summary of report definition.
    """

    #: A constant which can be used with the category property of a ReportDefinitionSummary.
    #: This constant has a value of "CUSTOM_REPORTS"
    CATEGORY_CUSTOM_REPORTS = "CUSTOM_REPORTS"

    #: A constant which can be used with the category property of a ReportDefinitionSummary.
    #: This constant has a value of "SUMMARY"
    CATEGORY_SUMMARY = "SUMMARY"

    #: A constant which can be used with the category property of a ReportDefinitionSummary.
    #: This constant has a value of "ACTIVITY_AUDITING"
    CATEGORY_ACTIVITY_AUDITING = "ACTIVITY_AUDITING"

    #: A constant which can be used with the data_source property of a ReportDefinitionSummary.
    #: This constant has a value of "EVENTS"
    DATA_SOURCE_EVENTS = "EVENTS"

    #: A constant which can be used with the data_source property of a ReportDefinitionSummary.
    #: This constant has a value of "ALERTS"
    DATA_SOURCE_ALERTS = "ALERTS"

    #: A constant which can be used with the lifecycle_state property of a ReportDefinitionSummary.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a ReportDefinitionSummary.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a ReportDefinitionSummary.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a ReportDefinitionSummary.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a ReportDefinitionSummary.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    def __init__(self, **kwargs):
        """
        Initializes a new ReportDefinitionSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this ReportDefinitionSummary.
        :type display_name: str

        :param id:
            The value to assign to the id property of this ReportDefinitionSummary.
        :type id: str

        :param category:
            The value to assign to the category property of this ReportDefinitionSummary.
            Allowed values for this property are: "CUSTOM_REPORTS", "SUMMARY", "ACTIVITY_AUDITING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type category: str

        :param description:
            The value to assign to the description property of this ReportDefinitionSummary.
        :type description: str

        :param is_seeded:
            The value to assign to the is_seeded property of this ReportDefinitionSummary.
        :type is_seeded: bool

        :param display_order:
            The value to assign to the display_order property of this ReportDefinitionSummary.
        :type display_order: int

        :param time_created:
            The value to assign to the time_created property of this ReportDefinitionSummary.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this ReportDefinitionSummary.
        :type time_updated: datetime

        :param compartment_id:
            The value to assign to the compartment_id property of this ReportDefinitionSummary.
        :type compartment_id: str

        :param data_source:
            The value to assign to the data_source property of this ReportDefinitionSummary.
            Allowed values for this property are: "EVENTS", "ALERTS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type data_source: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this ReportDefinitionSummary.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this ReportDefinitionSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this ReportDefinitionSummary.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'display_name': 'str',
            'id': 'str',
            'category': 'str',
            'description': 'str',
            'is_seeded': 'bool',
            'display_order': 'int',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'compartment_id': 'str',
            'data_source': 'str',
            'lifecycle_state': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'id': 'id',
            'category': 'category',
            'description': 'description',
            'is_seeded': 'isSeeded',
            'display_order': 'displayOrder',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'compartment_id': 'compartmentId',
            'data_source': 'dataSource',
            'lifecycle_state': 'lifecycleState',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._display_name = None
        self._id = None
        self._category = None
        self._description = None
        self._is_seeded = None
        self._display_order = None
        self._time_created = None
        self._time_updated = None
        self._compartment_id = None
        self._data_source = None
        self._lifecycle_state = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this ReportDefinitionSummary.
        Name of the report definition.


        :return: The display_name of this ReportDefinitionSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this ReportDefinitionSummary.
        Name of the report definition.


        :param display_name: The display_name of this ReportDefinitionSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def id(self):
        """
        **[Required]** Gets the id of this ReportDefinitionSummary.
        The OCID of the report definition.


        :return: The id of this ReportDefinitionSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ReportDefinitionSummary.
        The OCID of the report definition.


        :param id: The id of this ReportDefinitionSummary.
        :type: str
        """
        self._id = id

    @property
    def category(self):
        """
        Gets the category of this ReportDefinitionSummary.
        Specifies the name of the category that this report belongs to.

        Allowed values for this property are: "CUSTOM_REPORTS", "SUMMARY", "ACTIVITY_AUDITING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The category of this ReportDefinitionSummary.
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """
        Sets the category of this ReportDefinitionSummary.
        Specifies the name of the category that this report belongs to.


        :param category: The category of this ReportDefinitionSummary.
        :type: str
        """
        allowed_values = ["CUSTOM_REPORTS", "SUMMARY", "ACTIVITY_AUDITING"]
        if not value_allowed_none_or_none_sentinel(category, allowed_values):
            category = 'UNKNOWN_ENUM_VALUE'
        self._category = category

    @property
    def description(self):
        """
        Gets the description of this ReportDefinitionSummary.
        A description of the report definition.


        :return: The description of this ReportDefinitionSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ReportDefinitionSummary.
        A description of the report definition.


        :param description: The description of this ReportDefinitionSummary.
        :type: str
        """
        self._description = description

    @property
    def is_seeded(self):
        """
        Gets the is_seeded of this ReportDefinitionSummary.
        Signifies whether the definition is seeded or user defined. Values can either be 'true' or 'false'.


        :return: The is_seeded of this ReportDefinitionSummary.
        :rtype: bool
        """
        return self._is_seeded

    @is_seeded.setter
    def is_seeded(self, is_seeded):
        """
        Sets the is_seeded of this ReportDefinitionSummary.
        Signifies whether the definition is seeded or user defined. Values can either be 'true' or 'false'.


        :param is_seeded: The is_seeded of this ReportDefinitionSummary.
        :type: bool
        """
        self._is_seeded = is_seeded

    @property
    def display_order(self):
        """
        Gets the display_order of this ReportDefinitionSummary.
        Specifies how the report definitions are ordered in the display.


        :return: The display_order of this ReportDefinitionSummary.
        :rtype: int
        """
        return self._display_order

    @display_order.setter
    def display_order(self, display_order):
        """
        Sets the display_order of this ReportDefinitionSummary.
        Specifies how the report definitions are ordered in the display.


        :param display_order: The display_order of this ReportDefinitionSummary.
        :type: int
        """
        self._display_order = display_order

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this ReportDefinitionSummary.
        Specifies the time at which the report definition was created.


        :return: The time_created of this ReportDefinitionSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this ReportDefinitionSummary.
        Specifies the time at which the report definition was created.


        :param time_created: The time_created of this ReportDefinitionSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this ReportDefinitionSummary.
        The date and time of the report definition update in Data Safe.


        :return: The time_updated of this ReportDefinitionSummary.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this ReportDefinitionSummary.
        The date and time of the report definition update in Data Safe.


        :param time_updated: The time_updated of this ReportDefinitionSummary.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this ReportDefinitionSummary.
        The OCID of the compartment containing the report definition.


        :return: The compartment_id of this ReportDefinitionSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this ReportDefinitionSummary.
        The OCID of the compartment containing the report definition.


        :param compartment_id: The compartment_id of this ReportDefinitionSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def data_source(self):
        """
        Gets the data_source of this ReportDefinitionSummary.
        Specifies the name of a resource that provides data for the report. For example alerts, events.

        Allowed values for this property are: "EVENTS", "ALERTS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The data_source of this ReportDefinitionSummary.
        :rtype: str
        """
        return self._data_source

    @data_source.setter
    def data_source(self, data_source):
        """
        Sets the data_source of this ReportDefinitionSummary.
        Specifies the name of a resource that provides data for the report. For example alerts, events.


        :param data_source: The data_source of this ReportDefinitionSummary.
        :type: str
        """
        allowed_values = ["EVENTS", "ALERTS"]
        if not value_allowed_none_or_none_sentinel(data_source, allowed_values):
            data_source = 'UNKNOWN_ENUM_VALUE'
        self._data_source = data_source

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this ReportDefinitionSummary.
        The current state of the report

        Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this ReportDefinitionSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this ReportDefinitionSummary.
        The current state of the report


        :param lifecycle_state: The lifecycle_state of this ReportDefinitionSummary.
        :type: str
        """
        allowed_values = ["CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this ReportDefinitionSummary.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see `Resource Tags`__

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this ReportDefinitionSummary.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this ReportDefinitionSummary.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see `Resource Tags`__

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this ReportDefinitionSummary.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this ReportDefinitionSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this ReportDefinitionSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this ReportDefinitionSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this ReportDefinitionSummary.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateSensitiveTypeDetails(object):
    """
    Details to update a sensitive type.
    """

    #: A constant which can be used with the entity_type property of a UpdateSensitiveTypeDetails.
    #: This constant has a value of "SENSITIVE_TYPE"
    ENTITY_TYPE_SENSITIVE_TYPE = "SENSITIVE_TYPE"

    #: A constant which can be used with the entity_type property of a UpdateSensitiveTypeDetails.
    #: This constant has a value of "SENSITIVE_CATEGORY"
    ENTITY_TYPE_SENSITIVE_CATEGORY = "SENSITIVE_CATEGORY"

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateSensitiveTypeDetails object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.data_safe.models.UpdateSensitiveCategoryDetails`
        * :class:`~oci.data_safe.models.UpdateSensitiveTypePatternDetails`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param entity_type:
            The value to assign to the entity_type property of this UpdateSensitiveTypeDetails.
            Allowed values for this property are: "SENSITIVE_TYPE", "SENSITIVE_CATEGORY"
        :type entity_type: str

        :param display_name:
            The value to assign to the display_name property of this UpdateSensitiveTypeDetails.
        :type display_name: str

        :param short_name:
            The value to assign to the short_name property of this UpdateSensitiveTypeDetails.
        :type short_name: str

        :param description:
            The value to assign to the description property of this UpdateSensitiveTypeDetails.
        :type description: str

        :param parent_category_id:
            The value to assign to the parent_category_id property of this UpdateSensitiveTypeDetails.
        :type parent_category_id: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateSensitiveTypeDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateSensitiveTypeDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'entity_type': 'str',
            'display_name': 'str',
            'short_name': 'str',
            'description': 'str',
            'parent_category_id': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'entity_type': 'entityType',
            'display_name': 'displayName',
            'short_name': 'shortName',
            'description': 'description',
            'parent_category_id': 'parentCategoryId',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._entity_type = None
        self._display_name = None
        self._short_name = None
        self._description = None
        self._parent_category_id = None
        self._freeform_tags = None
        self._defined_tags = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['entityType']

        if type == 'SENSITIVE_CATEGORY':
            return 'UpdateSensitiveCategoryDetails'

        if type == 'SENSITIVE_TYPE':
            return 'UpdateSensitiveTypePatternDetails'
        else:
            return 'UpdateSensitiveTypeDetails'

    @property
    def entity_type(self):
        """
        **[Required]** Gets the entity_type of this UpdateSensitiveTypeDetails.
        The entity type. It can be either a sensitive type with regular expressions or a sensitive category used for
        grouping similar sensitive types.

        Allowed values for this property are: "SENSITIVE_TYPE", "SENSITIVE_CATEGORY"


        :return: The entity_type of this UpdateSensitiveTypeDetails.
        :rtype: str
        """
        return self._entity_type

    @entity_type.setter
    def entity_type(self, entity_type):
        """
        Sets the entity_type of this UpdateSensitiveTypeDetails.
        The entity type. It can be either a sensitive type with regular expressions or a sensitive category used for
        grouping similar sensitive types.


        :param entity_type: The entity_type of this UpdateSensitiveTypeDetails.
        :type: str
        """
        allowed_values = ["SENSITIVE_TYPE", "SENSITIVE_CATEGORY"]
        if not value_allowed_none_or_none_sentinel(entity_type, allowed_values):
            raise ValueError(
                "Invalid value for `entity_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._entity_type = entity_type

    @property
    def display_name(self):
        """
        Gets the display_name of this UpdateSensitiveTypeDetails.
        The display name of the sensitive type. The name does not have to be unique, and it's changeable.


        :return: The display_name of this UpdateSensitiveTypeDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this UpdateSensitiveTypeDetails.
        The display name of the sensitive type. The name does not have to be unique, and it's changeable.


        :param display_name: The display_name of this UpdateSensitiveTypeDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def short_name(self):
        """
        Gets the short_name of this UpdateSensitiveTypeDetails.
        The short name of the sensitive type.


        :return: The short_name of this UpdateSensitiveTypeDetails.
        :rtype: str
        """
        return self._short_name

    @short_name.setter
    def short_name(self, short_name):
        """
        Sets the short_name of this UpdateSensitiveTypeDetails.
        The short name of the sensitive type.


        :param short_name: The short_name of this UpdateSensitiveTypeDetails.
        :type: str
        """
        self._short_name = short_name

    @property
    def description(self):
        """
        Gets the description of this UpdateSensitiveTypeDetails.
        The description of the sensitive type.


        :return: The description of this UpdateSensitiveTypeDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this UpdateSensitiveTypeDetails.
        The description of the sensitive type.


        :param description: The description of this UpdateSensitiveTypeDetails.
        :type: str
        """
        self._description = description

    @property
    def parent_category_id(self):
        """
        Gets the parent_category_id of this UpdateSensitiveTypeDetails.
        The OCID of the parent sensitive category.


        :return: The parent_category_id of this UpdateSensitiveTypeDetails.
        :rtype: str
        """
        return self._parent_category_id

    @parent_category_id.setter
    def parent_category_id(self, parent_category_id):
        """
        Sets the parent_category_id of this UpdateSensitiveTypeDetails.
        The OCID of the parent sensitive category.


        :param parent_category_id: The parent_category_id of this UpdateSensitiveTypeDetails.
        :type: str
        """
        self._parent_category_id = parent_category_id

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this UpdateSensitiveTypeDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see `Resource Tags`__

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this UpdateSensitiveTypeDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this UpdateSensitiveTypeDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see `Resource Tags`__

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this UpdateSensitiveTypeDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this UpdateSensitiveTypeDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this UpdateSensitiveTypeDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this UpdateSensitiveTypeDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this UpdateSensitiveTypeDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .apdex import Apdex
from .apdex_rules import ApdexRules
from .apdex_rules_summary import ApdexRulesSummary
from .config import Config
from .config_collection import ConfigCollection
from .config_summary import ConfigSummary
from .create_apdex_rules_details import CreateApdexRulesDetails
from .create_config_details import CreateConfigDetails
from .create_metric_group_details import CreateMetricGroupDetails
from .create_span_filter_details import CreateSpanFilterDetails
from .dimension import Dimension
from .metric import Metric
from .metric_group import MetricGroup
from .metric_group_summary import MetricGroupSummary
from .span_filter import SpanFilter
from .span_filter_summary import SpanFilterSummary
from .update_apdex_rules_details import UpdateApdexRulesDetails
from .update_config_details import UpdateConfigDetails
from .update_metric_group_details import UpdateMetricGroupDetails
from .update_span_filter_details import UpdateSpanFilterDetails

# Maps type names to classes for apm_config services.
apm_config_type_mapping = {
    "Apdex": Apdex,
    "ApdexRules": ApdexRules,
    "ApdexRulesSummary": ApdexRulesSummary,
    "Config": Config,
    "ConfigCollection": ConfigCollection,
    "ConfigSummary": ConfigSummary,
    "CreateApdexRulesDetails": CreateApdexRulesDetails,
    "CreateConfigDetails": CreateConfigDetails,
    "CreateMetricGroupDetails": CreateMetricGroupDetails,
    "CreateSpanFilterDetails": CreateSpanFilterDetails,
    "Dimension": Dimension,
    "Metric": Metric,
    "MetricGroup": MetricGroup,
    "MetricGroupSummary": MetricGroupSummary,
    "SpanFilter": SpanFilter,
    "SpanFilterSummary": SpanFilterSummary,
    "UpdateApdexRulesDetails": UpdateApdexRulesDetails,
    "UpdateConfigDetails": UpdateConfigDetails,
    "UpdateMetricGroupDetails": UpdateMetricGroupDetails,
    "UpdateSpanFilterDetails": UpdateSpanFilterDetails
}



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CertificateAuthorityBundle(object):
    """
    The contents of the certificate, properties of the certificate (and certificate version), and user-provided contextual metadata for the certificate.
    """

    #: A constant which can be used with the stages property of a CertificateAuthorityBundle.
    #: This constant has a value of "CURRENT"
    STAGES_CURRENT = "CURRENT"

    #: A constant which can be used with the stages property of a CertificateAuthorityBundle.
    #: This constant has a value of "PENDING"
    STAGES_PENDING = "PENDING"

    #: A constant which can be used with the stages property of a CertificateAuthorityBundle.
    #: This constant has a value of "LATEST"
    STAGES_LATEST = "LATEST"

    #: A constant which can be used with the stages property of a CertificateAuthorityBundle.
    #: This constant has a value of "PREVIOUS"
    STAGES_PREVIOUS = "PREVIOUS"

    #: A constant which can be used with the stages property of a CertificateAuthorityBundle.
    #: This constant has a value of "DEPRECATED"
    STAGES_DEPRECATED = "DEPRECATED"

    #: A constant which can be used with the stages property of a CertificateAuthorityBundle.
    #: This constant has a value of "FAILED"
    STAGES_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new CertificateAuthorityBundle object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param certificate_authority_id:
            The value to assign to the certificate_authority_id property of this CertificateAuthorityBundle.
        :type certificate_authority_id: str

        :param certificate_authority_name:
            The value to assign to the certificate_authority_name property of this CertificateAuthorityBundle.
        :type certificate_authority_name: str

        :param serial_number:
            The value to assign to the serial_number property of this CertificateAuthorityBundle.
        :type serial_number: str

        :param certificate_pem:
            The value to assign to the certificate_pem property of this CertificateAuthorityBundle.
        :type certificate_pem: str

        :param cert_chain_pem:
            The value to assign to the cert_chain_pem property of this CertificateAuthorityBundle.
        :type cert_chain_pem: str

        :param version_name:
            The value to assign to the version_name property of this CertificateAuthorityBundle.
        :type version_name: str

        :param time_created:
            The value to assign to the time_created property of this CertificateAuthorityBundle.
        :type time_created: datetime

        :param version_number:
            The value to assign to the version_number property of this CertificateAuthorityBundle.
        :type version_number: int

        :param validity:
            The value to assign to the validity property of this CertificateAuthorityBundle.
        :type validity: oci.certificates.models.Validity

        :param stages:
            The value to assign to the stages property of this CertificateAuthorityBundle.
            Allowed values for items in this list are: "CURRENT", "PENDING", "LATEST", "PREVIOUS", "DEPRECATED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type stages: list[str]

        :param revocation_status:
            The value to assign to the revocation_status property of this CertificateAuthorityBundle.
        :type revocation_status: oci.certificates.models.RevocationStatus

        """
        self.swagger_types = {
            'certificate_authority_id': 'str',
            'certificate_authority_name': 'str',
            'serial_number': 'str',
            'certificate_pem': 'str',
            'cert_chain_pem': 'str',
            'version_name': 'str',
            'time_created': 'datetime',
            'version_number': 'int',
            'validity': 'Validity',
            'stages': 'list[str]',
            'revocation_status': 'RevocationStatus'
        }

        self.attribute_map = {
            'certificate_authority_id': 'certificateAuthorityId',
            'certificate_authority_name': 'certificateAuthorityName',
            'serial_number': 'serialNumber',
            'certificate_pem': 'certificatePem',
            'cert_chain_pem': 'certChainPem',
            'version_name': 'versionName',
            'time_created': 'timeCreated',
            'version_number': 'versionNumber',
            'validity': 'validity',
            'stages': 'stages',
            'revocation_status': 'revocationStatus'
        }

        self._certificate_authority_id = None
        self._certificate_authority_name = None
        self._serial_number = None
        self._certificate_pem = None
        self._cert_chain_pem = None
        self._version_name = None
        self._time_created = None
        self._version_number = None
        self._validity = None
        self._stages = None
        self._revocation_status = None

    @property
    def certificate_authority_id(self):
        """
        **[Required]** Gets the certificate_authority_id of this CertificateAuthorityBundle.
        The OCID of the certificate authority (CA).


        :return: The certificate_authority_id of this CertificateAuthorityBundle.
        :rtype: str
        """
        return self._certificate_authority_id

    @certificate_authority_id.setter
    def certificate_authority_id(self, certificate_authority_id):
        """
        Sets the certificate_authority_id of this CertificateAuthorityBundle.
        The OCID of the certificate authority (CA).


        :param certificate_authority_id: The certificate_authority_id of this CertificateAuthorityBundle.
        :type: str
        """
        self._certificate_authority_id = certificate_authority_id

    @property
    def certificate_authority_name(self):
        """
        **[Required]** Gets the certificate_authority_name of this CertificateAuthorityBundle.
        The name of the CA.


        :return: The certificate_authority_name of this CertificateAuthorityBundle.
        :rtype: str
        """
        return self._certificate_authority_name

    @certificate_authority_name.setter
    def certificate_authority_name(self, certificate_authority_name):
        """
        Sets the certificate_authority_name of this CertificateAuthorityBundle.
        The name of the CA.


        :param certificate_authority_name: The certificate_authority_name of this CertificateAuthorityBundle.
        :type: str
        """
        self._certificate_authority_name = certificate_authority_name

    @property
    def serial_number(self):
        """
        **[Required]** Gets the serial_number of this CertificateAuthorityBundle.
        A unique certificate identifier used in certificate revocation tracking, formatted as octets.
        Example: `03 AC FC FA CC B3 CB 02 B8 F8 DE F5 85 E7 7B FF`


        :return: The serial_number of this CertificateAuthorityBundle.
        :rtype: str
        """
        return self._serial_number

    @serial_number.setter
    def serial_number(self, serial_number):
        """
        Sets the serial_number of this CertificateAuthorityBundle.
        A unique certificate identifier used in certificate revocation tracking, formatted as octets.
        Example: `03 AC FC FA CC B3 CB 02 B8 F8 DE F5 85 E7 7B FF`


        :param serial_number: The serial_number of this CertificateAuthorityBundle.
        :type: str
        """
        self._serial_number = serial_number

    @property
    def certificate_pem(self):
        """
        **[Required]** Gets the certificate_pem of this CertificateAuthorityBundle.
        The certificate (in PEM format) for this CA version.


        :return: The certificate_pem of this CertificateAuthorityBundle.
        :rtype: str
        """
        return self._certificate_pem

    @certificate_pem.setter
    def certificate_pem(self, certificate_pem):
        """
        Sets the certificate_pem of this CertificateAuthorityBundle.
        The certificate (in PEM format) for this CA version.


        :param certificate_pem: The certificate_pem of this CertificateAuthorityBundle.
        :type: str
        """
        self._certificate_pem = certificate_pem

    @property
    def cert_chain_pem(self):
        """
        Gets the cert_chain_pem of this CertificateAuthorityBundle.
        The certificate chain (in PEM format) for this CA version.


        :return: The cert_chain_pem of this CertificateAuthorityBundle.
        :rtype: str
        """
        return self._cert_chain_pem

    @cert_chain_pem.setter
    def cert_chain_pem(self, cert_chain_pem):
        """
        Sets the cert_chain_pem of this CertificateAuthorityBundle.
        The certificate chain (in PEM format) for this CA version.


        :param cert_chain_pem: The cert_chain_pem of this CertificateAuthorityBundle.
        :type: str
        """
        self._cert_chain_pem = cert_chain_pem

    @property
    def version_name(self):
        """
        Gets the version_name of this CertificateAuthorityBundle.
        The name of the CA.


        :return: The version_name of this CertificateAuthorityBundle.
        :rtype: str
        """
        return self._version_name

    @version_name.setter
    def version_name(self, version_name):
        """
        Sets the version_name of this CertificateAuthorityBundle.
        The name of the CA.


        :param version_name: The version_name of this CertificateAuthorityBundle.
        :type: str
        """
        self._version_name = version_name

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this CertificateAuthorityBundle.
        A property indicating when the CA was created, expressed in `RFC 3339`__ timestamp format.
        Example: `2019-04-03T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this CertificateAuthorityBundle.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this CertificateAuthorityBundle.
        A property indicating when the CA was created, expressed in `RFC 3339`__ timestamp format.
        Example: `2019-04-03T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this CertificateAuthorityBundle.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def version_number(self):
        """
        **[Required]** Gets the version_number of this CertificateAuthorityBundle.
        The version number of the CA.


        :return: The version_number of this CertificateAuthorityBundle.
        :rtype: int
        """
        return self._version_number

    @version_number.setter
    def version_number(self, version_number):
        """
        Sets the version_number of this CertificateAuthorityBundle.
        The version number of the CA.


        :param version_number: The version_number of this CertificateAuthorityBundle.
        :type: int
        """
        self._version_number = version_number

    @property
    def validity(self):
        """
        **[Required]** Gets the validity of this CertificateAuthorityBundle.

        :return: The validity of this CertificateAuthorityBundle.
        :rtype: oci.certificates.models.Validity
        """
        return self._validity

    @validity.setter
    def validity(self, validity):
        """
        Sets the validity of this CertificateAuthorityBundle.

        :param validity: The validity of this CertificateAuthorityBundle.
        :type: oci.certificates.models.Validity
        """
        self._validity = validity

    @property
    def stages(self):
        """
        **[Required]** Gets the stages of this CertificateAuthorityBundle.
        A list of rotation states for this CA.

        Allowed values for items in this list are: "CURRENT", "PENDING", "LATEST", "PREVIOUS", "DEPRECATED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The stages of this CertificateAuthorityBundle.
        :rtype: list[str]
        """
        return self._stages

    @stages.setter
    def stages(self, stages):
        """
        Sets the stages of this CertificateAuthorityBundle.
        A list of rotation states for this CA.


        :param stages: The stages of this CertificateAuthorityBundle.
        :type: list[str]
        """
        allowed_values = ["CURRENT", "PENDING", "LATEST", "PREVIOUS", "DEPRECATED", "FAILED"]
        if stages:
            stages[:] = ['UNKNOWN_ENUM_VALUE' if not value_allowed_none_or_none_sentinel(x, allowed_values) else x for x in stages]
        self._stages = stages

    @property
    def revocation_status(self):
        """
        Gets the revocation_status of this CertificateAuthorityBundle.

        :return: The revocation_status of this CertificateAuthorityBundle.
        :rtype: oci.certificates.models.RevocationStatus
        """
        return self._revocation_status

    @revocation_status.setter
    def revocation_status(self, revocation_status):
        """
        Sets the revocation_status of this CertificateAuthorityBundle.

        :param revocation_status: The revocation_status of this CertificateAuthorityBundle.
        :type: oci.certificates.models.RevocationStatus
        """
        self._revocation_status = revocation_status

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateLibraryMaskingFormatDetails(object):
    """
    Details to create a library masking format, which can have one or more format entries. A format
    entry can be a basic masking format such as Random Number, or it can be a library masking format.
    The combined output of all the format entries is used for masking. It provides the flexibility
    to define a masking format that can generate different parts of a data value separately and then
    combine them to get the final data value for masking. Note that you cannot define masking
    condition in a library masking format.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateLibraryMaskingFormatDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this CreateLibraryMaskingFormatDetails.
        :type display_name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateLibraryMaskingFormatDetails.
        :type compartment_id: str

        :param description:
            The value to assign to the description property of this CreateLibraryMaskingFormatDetails.
        :type description: str

        :param sensitive_type_ids:
            The value to assign to the sensitive_type_ids property of this CreateLibraryMaskingFormatDetails.
        :type sensitive_type_ids: list[str]

        :param format_entries:
            The value to assign to the format_entries property of this CreateLibraryMaskingFormatDetails.
        :type format_entries: list[oci.data_safe.models.FormatEntry]

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateLibraryMaskingFormatDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateLibraryMaskingFormatDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'display_name': 'str',
            'compartment_id': 'str',
            'description': 'str',
            'sensitive_type_ids': 'list[str]',
            'format_entries': 'list[FormatEntry]',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'compartment_id': 'compartmentId',
            'description': 'description',
            'sensitive_type_ids': 'sensitiveTypeIds',
            'format_entries': 'formatEntries',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._display_name = None
        self._compartment_id = None
        self._description = None
        self._sensitive_type_ids = None
        self._format_entries = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def display_name(self):
        """
        Gets the display_name of this CreateLibraryMaskingFormatDetails.
        The display name of the library masking format. The name does not have to be unique, and it's changeable.


        :return: The display_name of this CreateLibraryMaskingFormatDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateLibraryMaskingFormatDetails.
        The display name of the library masking format. The name does not have to be unique, and it's changeable.


        :param display_name: The display_name of this CreateLibraryMaskingFormatDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateLibraryMaskingFormatDetails.
        The OCID of the compartment where the library masking format should be created.


        :return: The compartment_id of this CreateLibraryMaskingFormatDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateLibraryMaskingFormatDetails.
        The OCID of the compartment where the library masking format should be created.


        :param compartment_id: The compartment_id of this CreateLibraryMaskingFormatDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def description(self):
        """
        Gets the description of this CreateLibraryMaskingFormatDetails.
        The description of the library masking format.


        :return: The description of this CreateLibraryMaskingFormatDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CreateLibraryMaskingFormatDetails.
        The description of the library masking format.


        :param description: The description of this CreateLibraryMaskingFormatDetails.
        :type: str
        """
        self._description = description

    @property
    def sensitive_type_ids(self):
        """
        Gets the sensitive_type_ids of this CreateLibraryMaskingFormatDetails.
        An array of OCIDs of the sensitive types compatible with the library masking format. It helps track the sensitive types for which the library masking format is being created.


        :return: The sensitive_type_ids of this CreateLibraryMaskingFormatDetails.
        :rtype: list[str]
        """
        return self._sensitive_type_ids

    @sensitive_type_ids.setter
    def sensitive_type_ids(self, sensitive_type_ids):
        """
        Sets the sensitive_type_ids of this CreateLibraryMaskingFormatDetails.
        An array of OCIDs of the sensitive types compatible with the library masking format. It helps track the sensitive types for which the library masking format is being created.


        :param sensitive_type_ids: The sensitive_type_ids of this CreateLibraryMaskingFormatDetails.
        :type: list[str]
        """
        self._sensitive_type_ids = sensitive_type_ids

    @property
    def format_entries(self):
        """
        **[Required]** Gets the format_entries of this CreateLibraryMaskingFormatDetails.
        An array of format entries. The combined output of all the format entries is used for masking.


        :return: The format_entries of this CreateLibraryMaskingFormatDetails.
        :rtype: list[oci.data_safe.models.FormatEntry]
        """
        return self._format_entries

    @format_entries.setter
    def format_entries(self, format_entries):
        """
        Sets the format_entries of this CreateLibraryMaskingFormatDetails.
        An array of format entries. The combined output of all the format entries is used for masking.


        :param format_entries: The format_entries of this CreateLibraryMaskingFormatDetails.
        :type: list[oci.data_safe.models.FormatEntry]
        """
        self._format_entries = format_entries

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateLibraryMaskingFormatDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see `Resource Tags`__

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CreateLibraryMaskingFormatDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateLibraryMaskingFormatDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see `Resource Tags`__

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CreateLibraryMaskingFormatDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateLibraryMaskingFormatDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CreateLibraryMaskingFormatDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateLibraryMaskingFormatDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CreateLibraryMaskingFormatDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .access_control_rule import AccessControlRule
from .action import Action
from .allow_action import AllowAction
from .change_network_address_list_compartment_details import ChangeNetworkAddressListCompartmentDetails
from .change_resource_compartment_details import ChangeResourceCompartmentDetails
from .change_web_app_firewall_compartment_details import ChangeWebAppFirewallCompartmentDetails
from .change_web_app_firewall_policy_compartment_details import ChangeWebAppFirewallPolicyCompartmentDetails
from .check_action import CheckAction
from .collaborative_capability_weight import CollaborativeCapabilityWeight
from .collaborative_capability_weight_override import CollaborativeCapabilityWeightOverride
from .create_network_address_list_addresses_details import CreateNetworkAddressListAddressesDetails
from .create_network_address_list_details import CreateNetworkAddressListDetails
from .create_network_address_list_vcn_addresses_details import CreateNetworkAddressListVcnAddressesDetails
from .create_web_app_firewall_details import CreateWebAppFirewallDetails
from .create_web_app_firewall_load_balancer_details import CreateWebAppFirewallLoadBalancerDetails
from .create_web_app_firewall_policy_details import CreateWebAppFirewallPolicyDetails
from .http_response_body import HttpResponseBody
from .network_address_list import NetworkAddressList
from .network_address_list_addresses import NetworkAddressListAddresses
from .network_address_list_addresses_summary import NetworkAddressListAddressesSummary
from .network_address_list_collection import NetworkAddressListCollection
from .network_address_list_summary import NetworkAddressListSummary
from .network_address_list_vcn_addresses import NetworkAddressListVcnAddresses
from .network_address_list_vcn_addresses_summary import NetworkAddressListVcnAddressesSummary
from .private_addresses import PrivateAddresses
from .protection_capability import ProtectionCapability
from .protection_capability_collection import ProtectionCapabilityCollection
from .protection_capability_exclusions import ProtectionCapabilityExclusions
from .protection_capability_group_tag_collection import ProtectionCapabilityGroupTagCollection
from .protection_capability_group_tag_summary import ProtectionCapabilityGroupTagSummary
from .protection_capability_settings import ProtectionCapabilitySettings
from .protection_capability_summary import ProtectionCapabilitySummary
from .protection_rule import ProtectionRule
from .request_access_control import RequestAccessControl
from .request_protection import RequestProtection
from .request_rate_limiting import RequestRateLimiting
from .request_rate_limiting_configuration import RequestRateLimitingConfiguration
from .request_rate_limiting_rule import RequestRateLimitingRule
from .response_access_control import ResponseAccessControl
from .response_header import ResponseHeader
from .response_protection import ResponseProtection
from .return_http_response_action import ReturnHttpResponseAction
from .static_text_http_response_body import StaticTextHttpResponseBody
from .update_network_address_list_addresses_details import UpdateNetworkAddressListAddressesDetails
from .update_network_address_list_details import UpdateNetworkAddressListDetails
from .update_network_address_list_vcn_addresses_details import UpdateNetworkAddressListVcnAddressesDetails
from .update_web_app_firewall_details import UpdateWebAppFirewallDetails
from .update_web_app_firewall_policy_details import UpdateWebAppFirewallPolicyDetails
from .web_app_firewall import WebAppFirewall
from .web_app_firewall_collection import WebAppFirewallCollection
from .web_app_firewall_load_balancer import WebAppFirewallLoadBalancer
from .web_app_firewall_load_balancer_summary import WebAppFirewallLoadBalancerSummary
from .web_app_firewall_policy import WebAppFirewallPolicy
from .web_app_firewall_policy_collection import WebAppFirewallPolicyCollection
from .web_app_firewall_policy_rule import WebAppFirewallPolicyRule
from .web_app_firewall_policy_summary import WebAppFirewallPolicySummary
from .web_app_firewall_summary import WebAppFirewallSummary
from .work_request import WorkRequest
from .work_request_collection import WorkRequestCollection
from .work_request_error import WorkRequestError
from .work_request_error_collection import WorkRequestErrorCollection
from .work_request_log_entry import WorkRequestLogEntry
from .work_request_log_entry_collection import WorkRequestLogEntryCollection
from .work_request_resource import WorkRequestResource

# Maps type names to classes for waf services.
waf_type_mapping = {
    "AccessControlRule": AccessControlRule,
    "Action": Action,
    "AllowAction": AllowAction,
    "ChangeNetworkAddressListCompartmentDetails": ChangeNetworkAddressListCompartmentDetails,
    "ChangeResourceCompartmentDetails": ChangeResourceCompartmentDetails,
    "ChangeWebAppFirewallCompartmentDetails": ChangeWebAppFirewallCompartmentDetails,
    "ChangeWebAppFirewallPolicyCompartmentDetails": ChangeWebAppFirewallPolicyCompartmentDetails,
    "CheckAction": CheckAction,
    "CollaborativeCapabilityWeight": CollaborativeCapabilityWeight,
    "CollaborativeCapabilityWeightOverride": CollaborativeCapabilityWeightOverride,
    "CreateNetworkAddressListAddressesDetails": CreateNetworkAddressListAddressesDetails,
    "CreateNetworkAddressListDetails": CreateNetworkAddressListDetails,
    "CreateNetworkAddressListVcnAddressesDetails": CreateNetworkAddressListVcnAddressesDetails,
    "CreateWebAppFirewallDetails": CreateWebAppFirewallDetails,
    "CreateWebAppFirewallLoadBalancerDetails": CreateWebAppFirewallLoadBalancerDetails,
    "CreateWebAppFirewallPolicyDetails": CreateWebAppFirewallPolicyDetails,
    "HttpResponseBody": HttpResponseBody,
    "NetworkAddressList": NetworkAddressList,
    "NetworkAddressListAddresses": NetworkAddressListAddresses,
    "NetworkAddressListAddressesSummary": NetworkAddressListAddressesSummary,
    "NetworkAddressListCollection": NetworkAddressListCollection,
    "NetworkAddressListSummary": NetworkAddressListSummary,
    "NetworkAddressListVcnAddresses": NetworkAddressListVcnAddresses,
    "NetworkAddressListVcnAddressesSummary": NetworkAddressListVcnAddressesSummary,
    "PrivateAddresses": PrivateAddresses,
    "ProtectionCapability": ProtectionCapability,
    "ProtectionCapabilityCollection": ProtectionCapabilityCollection,
    "ProtectionCapabilityExclusions": ProtectionCapabilityExclusions,
    "ProtectionCapabilityGroupTagCollection": ProtectionCapabilityGroupTagCollection,
    "ProtectionCapabilityGroupTagSummary": ProtectionCapabilityGroupTagSummary,
    "ProtectionCapabilitySettings": ProtectionCapabilitySettings,
    "ProtectionCapabilitySummary": ProtectionCapabilitySummary,
    "ProtectionRule": ProtectionRule,
    "RequestAccessControl": RequestAccessControl,
    "RequestProtection": RequestProtection,
    "RequestRateLimiting": RequestRateLimiting,
    "RequestRateLimitingConfiguration": RequestRateLimitingConfiguration,
    "RequestRateLimitingRule": RequestRateLimitingRule,
    "ResponseAccessControl": ResponseAccessControl,
    "ResponseHeader": ResponseHeader,
    "ResponseProtection": ResponseProtection,
    "ReturnHttpResponseAction": ReturnHttpResponseAction,
    "StaticTextHttpResponseBody": StaticTextHttpResponseBody,
    "UpdateNetworkAddressListAddressesDetails": UpdateNetworkAddressListAddressesDetails,
    "UpdateNetworkAddressListDetails": UpdateNetworkAddressListDetails,
    "UpdateNetworkAddressListVcnAddressesDetails": UpdateNetworkAddressListVcnAddressesDetails,
    "UpdateWebAppFirewallDetails": UpdateWebAppFirewallDetails,
    "UpdateWebAppFirewallPolicyDetails": UpdateWebAppFirewallPolicyDetails,
    "WebAppFirewall": WebAppFirewall,
    "WebAppFirewallCollection": WebAppFirewallCollection,
    "WebAppFirewallLoadBalancer": WebAppFirewallLoadBalancer,
    "WebAppFirewallLoadBalancerSummary": WebAppFirewallLoadBalancerSummary,
    "WebAppFirewallPolicy": WebAppFirewallPolicy,
    "WebAppFirewallPolicyCollection": WebAppFirewallPolicyCollection,
    "WebAppFirewallPolicyRule": WebAppFirewallPolicyRule,
    "WebAppFirewallPolicySummary": WebAppFirewallPolicySummary,
    "WebAppFirewallSummary": WebAppFirewallSummary,
    "WorkRequest": WorkRequest,
    "WorkRequestCollection": WorkRequestCollection,
    "WorkRequestError": WorkRequestError,
    "WorkRequestErrorCollection": WorkRequestErrorCollection,
    "WorkRequestLogEntry": WorkRequestLogEntry,
    "WorkRequestLogEntryCollection": WorkRequestLogEntryCollection,
    "WorkRequestResource": WorkRequestResource
}



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .payment_detail import PaymentDetail
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PaypalPaymentDetail(PaymentDetail):
    """
    PayPal Payment related details
    """

    def __init__(self, **kwargs):
        """
        Initializes a new PaypalPaymentDetail object with values from keyword arguments. The default value of the :py:attr:`~oci.osp_gateway.models.PaypalPaymentDetail.payment_method` attribute
        of this class is ``PAYPAL`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param time_paid_on:
            The value to assign to the time_paid_on property of this PaypalPaymentDetail.
        :type time_paid_on: datetime

        :param paid_by:
            The value to assign to the paid_by property of this PaypalPaymentDetail.
        :type paid_by: str

        :param payment_method:
            The value to assign to the payment_method property of this PaypalPaymentDetail.
            Allowed values for this property are: "CREDIT_CARD", "PAYPAL", "OTHER"
        :type payment_method: str

        :param amount_paid:
            The value to assign to the amount_paid property of this PaypalPaymentDetail.
        :type amount_paid: float

        :param paypal_id:
            The value to assign to the paypal_id property of this PaypalPaymentDetail.
        :type paypal_id: str

        :param paypal_reference:
            The value to assign to the paypal_reference property of this PaypalPaymentDetail.
        :type paypal_reference: str

        """
        self.swagger_types = {
            'time_paid_on': 'datetime',
            'paid_by': 'str',
            'payment_method': 'str',
            'amount_paid': 'float',
            'paypal_id': 'str',
            'paypal_reference': 'str'
        }

        self.attribute_map = {
            'time_paid_on': 'timePaidOn',
            'paid_by': 'paidBy',
            'payment_method': 'paymentMethod',
            'amount_paid': 'amountPaid',
            'paypal_id': 'paypalId',
            'paypal_reference': 'paypalReference'
        }

        self._time_paid_on = None
        self._paid_by = None
        self._payment_method = None
        self._amount_paid = None
        self._paypal_id = None
        self._paypal_reference = None
        self._payment_method = 'PAYPAL'

    @property
    def paypal_id(self):
        """
        Gets the paypal_id of this PaypalPaymentDetail.
        The id (email address) of the paypal payment


        :return: The paypal_id of this PaypalPaymentDetail.
        :rtype: str
        """
        return self._paypal_id

    @paypal_id.setter
    def paypal_id(self, paypal_id):
        """
        Sets the paypal_id of this PaypalPaymentDetail.
        The id (email address) of the paypal payment


        :param paypal_id: The paypal_id of this PaypalPaymentDetail.
        :type: str
        """
        self._paypal_id = paypal_id

    @property
    def paypal_reference(self):
        """
        Gets the paypal_reference of this PaypalPaymentDetail.
        paypal payment reference


        :return: The paypal_reference of this PaypalPaymentDetail.
        :rtype: str
        """
        return self._paypal_reference

    @paypal_reference.setter
    def paypal_reference(self, paypal_reference):
        """
        Sets the paypal_reference of this PaypalPaymentDetail.
        paypal payment reference


        :param paypal_reference: The paypal_reference of this PaypalPaymentDetail.
        :type: str
        """
        self._paypal_reference = paypal_reference

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ProtectionRuleAction(object):
    """
    A protection rule key and the associated action to apply to that rule.
    """

    #: A constant which can be used with the action property of a ProtectionRuleAction.
    #: This constant has a value of "OFF"
    ACTION_OFF = "OFF"

    #: A constant which can be used with the action property of a ProtectionRuleAction.
    #: This constant has a value of "DETECT"
    ACTION_DETECT = "DETECT"

    #: A constant which can be used with the action property of a ProtectionRuleAction.
    #: This constant has a value of "BLOCK"
    ACTION_BLOCK = "BLOCK"

    def __init__(self, **kwargs):
        """
        Initializes a new ProtectionRuleAction object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this ProtectionRuleAction.
        :type key: str

        :param action:
            The value to assign to the action property of this ProtectionRuleAction.
            Allowed values for this property are: "OFF", "DETECT", "BLOCK"
        :type action: str

        :param exclusions:
            The value to assign to the exclusions property of this ProtectionRuleAction.
        :type exclusions: list[oci.waas.models.ProtectionRuleExclusion]

        """
        self.swagger_types = {
            'key': 'str',
            'action': 'str',
            'exclusions': 'list[ProtectionRuleExclusion]'
        }

        self.attribute_map = {
            'key': 'key',
            'action': 'action',
            'exclusions': 'exclusions'
        }

        self._key = None
        self._action = None
        self._exclusions = None

    @property
    def key(self):
        """
        **[Required]** Gets the key of this ProtectionRuleAction.
        The unique key of the protection rule.


        :return: The key of this ProtectionRuleAction.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this ProtectionRuleAction.
        The unique key of the protection rule.


        :param key: The key of this ProtectionRuleAction.
        :type: str
        """
        self._key = key

    @property
    def action(self):
        """
        **[Required]** Gets the action of this ProtectionRuleAction.
        The action to apply to the protection rule. If unspecified, defaults to `OFF`.

        Allowed values for this property are: "OFF", "DETECT", "BLOCK"


        :return: The action of this ProtectionRuleAction.
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """
        Sets the action of this ProtectionRuleAction.
        The action to apply to the protection rule. If unspecified, defaults to `OFF`.


        :param action: The action of this ProtectionRuleAction.
        :type: str
        """
        allowed_values = ["OFF", "DETECT", "BLOCK"]
        if not value_allowed_none_or_none_sentinel(action, allowed_values):
            raise ValueError(
                "Invalid value for `action`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._action = action

    @property
    def exclusions(self):
        """
        Gets the exclusions of this ProtectionRuleAction.
        The types of requests excluded from the protection rule action. If the requests matches the criteria in the `exclusions`, the protection rule action will not be executed.


        :return: The exclusions of this ProtectionRuleAction.
        :rtype: list[oci.waas.models.ProtectionRuleExclusion]
        """
        return self._exclusions

    @exclusions.setter
    def exclusions(self, exclusions):
        """
        Sets the exclusions of this ProtectionRuleAction.
        The types of requests excluded from the protection rule action. If the requests matches the criteria in the `exclusions`, the protection rule action will not be executed.


        :param exclusions: The exclusions of this ProtectionRuleAction.
        :type: list[oci.waas.models.ProtectionRuleExclusion]
        """
        self._exclusions = exclusions

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AddAutoScalePolicyDetails(object):
    """
    Policy definition for the autoscale configuration.

    An autoscaling policy is part of an autoscaling configuration. For more information, see
    `Autoscaling`__

    You can create following type of autoscaling policies:

    - **MetricBasedVerticalScalingPolicy:** Vertical autoscaling action is triggered when a performance metric exceeds a threshold
    - **MetricBasedHorizontalScalingPolicy:** Horizontal autoscaling action is triggered when a performance metric exceeds a threshold
    - **ScheduleBasedVerticalScalingPolicy:** Vertical autoscaling action is triggered at the specific times that you schedule.
    - **ScheduleBasedHorizontalScalingPolicy:** Horizontal autoscaling action is triggered at the specific times that you schedule.

    An autoscaling configuration can have one of above supported policies.

    __ https://docs.cloud.oracle.com/iaas/Content/bigdata/create-cluster.htm#cluster-autoscale
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AddAutoScalePolicyDetails object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.bds.models.AddMetricBasedHorizontalScalingPolicyDetails`
        * :class:`~oci.bds.models.AddScheduleBasedVerticalScalingPolicyDetails`
        * :class:`~oci.bds.models.AddScheduleBasedHorizontalScalingPolicyDetails`
        * :class:`~oci.bds.models.AddMetricBasedVerticalScalingPolicyDetails`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param policy_type:
            The value to assign to the policy_type property of this AddAutoScalePolicyDetails.
        :type policy_type: str

        """
        self.swagger_types = {
            'policy_type': 'str'
        }

        self.attribute_map = {
            'policy_type': 'policyType'
        }

        self._policy_type = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['policyType']

        if type == 'METRIC_BASED_HORIZONTAL_SCALING_POLICY':
            return 'AddMetricBasedHorizontalScalingPolicyDetails'

        if type == 'SCHEDULE_BASED_VERTICAL_SCALING_POLICY':
            return 'AddScheduleBasedVerticalScalingPolicyDetails'

        if type == 'SCHEDULE_BASED_HORIZONTAL_SCALING_POLICY':
            return 'AddScheduleBasedHorizontalScalingPolicyDetails'

        if type == 'METRIC_BASED_VERTICAL_SCALING_POLICY':
            return 'AddMetricBasedVerticalScalingPolicyDetails'
        else:
            return 'AddAutoScalePolicyDetails'

    @property
    def policy_type(self):
        """
        **[Required]** Gets the policy_type of this AddAutoScalePolicyDetails.
        Type of autoscaling policy.


        :return: The policy_type of this AddAutoScalePolicyDetails.
        :rtype: str
        """
        return self._policy_type

    @policy_type.setter
    def policy_type(self, policy_type):
        """
        Sets the policy_type of this AddAutoScalePolicyDetails.
        Type of autoscaling policy.


        :param policy_type: The policy_type of this AddAutoScalePolicyDetails.
        :type: str
        """
        self._policy_type = policy_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ModifiedAttributes(object):
    """
    The attributes of a sensitive column that have been modified in the target database. It's populated only in the case
    of MODIFIED discovery results and shows the new values of the modified attributes.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ModifiedAttributes object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param app_defined_child_column_keys:
            The value to assign to the app_defined_child_column_keys property of this ModifiedAttributes.
        :type app_defined_child_column_keys: list[str]

        :param db_defined_child_column_keys:
            The value to assign to the db_defined_child_column_keys property of this ModifiedAttributes.
        :type db_defined_child_column_keys: list[str]

        """
        self.swagger_types = {
            'app_defined_child_column_keys': 'list[str]',
            'db_defined_child_column_keys': 'list[str]'
        }

        self.attribute_map = {
            'app_defined_child_column_keys': 'appDefinedChildColumnKeys',
            'db_defined_child_column_keys': 'dbDefinedChildColumnKeys'
        }

        self._app_defined_child_column_keys = None
        self._db_defined_child_column_keys = None

    @property
    def app_defined_child_column_keys(self):
        """
        Gets the app_defined_child_column_keys of this ModifiedAttributes.
        Unique keys identifying the columns that are application-level (non-dictionary) children of the sensitive column.


        :return: The app_defined_child_column_keys of this ModifiedAttributes.
        :rtype: list[str]
        """
        return self._app_defined_child_column_keys

    @app_defined_child_column_keys.setter
    def app_defined_child_column_keys(self, app_defined_child_column_keys):
        """
        Sets the app_defined_child_column_keys of this ModifiedAttributes.
        Unique keys identifying the columns that are application-level (non-dictionary) children of the sensitive column.


        :param app_defined_child_column_keys: The app_defined_child_column_keys of this ModifiedAttributes.
        :type: list[str]
        """
        self._app_defined_child_column_keys = app_defined_child_column_keys

    @property
    def db_defined_child_column_keys(self):
        """
        Gets the db_defined_child_column_keys of this ModifiedAttributes.
        Unique keys identifying the columns that are database-level (dictionary-defined) children of the sensitive column.


        :return: The db_defined_child_column_keys of this ModifiedAttributes.
        :rtype: list[str]
        """
        return self._db_defined_child_column_keys

    @db_defined_child_column_keys.setter
    def db_defined_child_column_keys(self, db_defined_child_column_keys):
        """
        Sets the db_defined_child_column_keys of this ModifiedAttributes.
        Unique keys identifying the columns that are database-level (dictionary-defined) children of the sensitive column.


        :param db_defined_child_column_keys: The db_defined_child_column_keys of this ModifiedAttributes.
        :type: list[str]
        """
        self._db_defined_child_column_keys = db_defined_child_column_keys

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .update_auto_scale_policy_details import UpdateAutoScalePolicyDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateMetricBasedVerticalScalingPolicyDetails(UpdateAutoScalePolicyDetails):
    """
    Update details of a metric based vertical autoscaling policy.

    In a metric-based autoscaling policy, an autoscaling action is triggered when a performance metric exceeds a threshold.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateMetricBasedVerticalScalingPolicyDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.bds.models.UpdateMetricBasedVerticalScalingPolicyDetails.policy_type` attribute
        of this class is ``METRIC_BASED_VERTICAL_SCALING_POLICY`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param policy_type:
            The value to assign to the policy_type property of this UpdateMetricBasedVerticalScalingPolicyDetails.
        :type policy_type: str

        :param scale_up_config:
            The value to assign to the scale_up_config property of this UpdateMetricBasedVerticalScalingPolicyDetails.
        :type scale_up_config: oci.bds.models.MetricBasedVerticalScaleUpConfig

        :param scale_down_config:
            The value to assign to the scale_down_config property of this UpdateMetricBasedVerticalScalingPolicyDetails.
        :type scale_down_config: oci.bds.models.MetricBasedVerticalScaleDownConfig

        """
        self.swagger_types = {
            'policy_type': 'str',
            'scale_up_config': 'MetricBasedVerticalScaleUpConfig',
            'scale_down_config': 'MetricBasedVerticalScaleDownConfig'
        }

        self.attribute_map = {
            'policy_type': 'policyType',
            'scale_up_config': 'scaleUpConfig',
            'scale_down_config': 'scaleDownConfig'
        }

        self._policy_type = None
        self._scale_up_config = None
        self._scale_down_config = None
        self._policy_type = 'METRIC_BASED_VERTICAL_SCALING_POLICY'

    @property
    def scale_up_config(self):
        """
        Gets the scale_up_config of this UpdateMetricBasedVerticalScalingPolicyDetails.

        :return: The scale_up_config of this UpdateMetricBasedVerticalScalingPolicyDetails.
        :rtype: oci.bds.models.MetricBasedVerticalScaleUpConfig
        """
        return self._scale_up_config

    @scale_up_config.setter
    def scale_up_config(self, scale_up_config):
        """
        Sets the scale_up_config of this UpdateMetricBasedVerticalScalingPolicyDetails.

        :param scale_up_config: The scale_up_config of this UpdateMetricBasedVerticalScalingPolicyDetails.
        :type: oci.bds.models.MetricBasedVerticalScaleUpConfig
        """
        self._scale_up_config = scale_up_config

    @property
    def scale_down_config(self):
        """
        Gets the scale_down_config of this UpdateMetricBasedVerticalScalingPolicyDetails.

        :return: The scale_down_config of this UpdateMetricBasedVerticalScalingPolicyDetails.
        :rtype: oci.bds.models.MetricBasedVerticalScaleDownConfig
        """
        return self._scale_down_config

    @scale_down_config.setter
    def scale_down_config(self, scale_down_config):
        """
        Sets the scale_down_config of this UpdateMetricBasedVerticalScalingPolicyDetails.

        :param scale_down_config: The scale_down_config of this UpdateMetricBasedVerticalScalingPolicyDetails.
        :type: oci.bds.models.MetricBasedVerticalScaleDownConfig
        """
        self._scale_down_config = scale_down_config

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ResourceUsageSummary(object):
    """
    Contains resource usage summary
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ResourceUsageSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param exadata_insight_id:
            The value to assign to the exadata_insight_id property of this ResourceUsageSummary.
        :type exadata_insight_id: str

        :param usage:
            The value to assign to the usage property of this ResourceUsageSummary.
        :type usage: float

        :param capacity:
            The value to assign to the capacity property of this ResourceUsageSummary.
        :type capacity: float

        :param utilization_percent:
            The value to assign to the utilization_percent property of this ResourceUsageSummary.
        :type utilization_percent: float

        :param usage_change_percent:
            The value to assign to the usage_change_percent property of this ResourceUsageSummary.
        :type usage_change_percent: float

        """
        self.swagger_types = {
            'exadata_insight_id': 'str',
            'usage': 'float',
            'capacity': 'float',
            'utilization_percent': 'float',
            'usage_change_percent': 'float'
        }

        self.attribute_map = {
            'exadata_insight_id': 'exadataInsightId',
            'usage': 'usage',
            'capacity': 'capacity',
            'utilization_percent': 'utilizationPercent',
            'usage_change_percent': 'usageChangePercent'
        }

        self._exadata_insight_id = None
        self._usage = None
        self._capacity = None
        self._utilization_percent = None
        self._usage_change_percent = None

    @property
    def exadata_insight_id(self):
        """
        **[Required]** Gets the exadata_insight_id of this ResourceUsageSummary.
        The `OCID`__ of the Exadata insight.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The exadata_insight_id of this ResourceUsageSummary.
        :rtype: str
        """
        return self._exadata_insight_id

    @exadata_insight_id.setter
    def exadata_insight_id(self, exadata_insight_id):
        """
        Sets the exadata_insight_id of this ResourceUsageSummary.
        The `OCID`__ of the Exadata insight.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param exadata_insight_id: The exadata_insight_id of this ResourceUsageSummary.
        :type: str
        """
        self._exadata_insight_id = exadata_insight_id

    @property
    def usage(self):
        """
        **[Required]** Gets the usage of this ResourceUsageSummary.
        Total amount used of the resource metric type (CPU, STORAGE).


        :return: The usage of this ResourceUsageSummary.
        :rtype: float
        """
        return self._usage

    @usage.setter
    def usage(self, usage):
        """
        Sets the usage of this ResourceUsageSummary.
        Total amount used of the resource metric type (CPU, STORAGE).


        :param usage: The usage of this ResourceUsageSummary.
        :type: float
        """
        self._usage = usage

    @property
    def capacity(self):
        """
        **[Required]** Gets the capacity of this ResourceUsageSummary.
        The maximum allocated amount of the resource metric type  (CPU, STORAGE).


        :return: The capacity of this ResourceUsageSummary.
        :rtype: float
        """
        return self._capacity

    @capacity.setter
    def capacity(self, capacity):
        """
        Sets the capacity of this ResourceUsageSummary.
        The maximum allocated amount of the resource metric type  (CPU, STORAGE).


        :param capacity: The capacity of this ResourceUsageSummary.
        :type: float
        """
        self._capacity = capacity

    @property
    def utilization_percent(self):
        """
        **[Required]** Gets the utilization_percent of this ResourceUsageSummary.
        Resource utilization in percentage


        :return: The utilization_percent of this ResourceUsageSummary.
        :rtype: float
        """
        return self._utilization_percent

    @utilization_percent.setter
    def utilization_percent(self, utilization_percent):
        """
        Sets the utilization_percent of this ResourceUsageSummary.
        Resource utilization in percentage


        :param utilization_percent: The utilization_percent of this ResourceUsageSummary.
        :type: float
        """
        self._utilization_percent = utilization_percent

    @property
    def usage_change_percent(self):
        """
        **[Required]** Gets the usage_change_percent of this ResourceUsageSummary.
        Change in resource utilization in percentage


        :return: The usage_change_percent of this ResourceUsageSummary.
        :rtype: float
        """
        return self._usage_change_percent

    @usage_change_percent.setter
    def usage_change_percent(self, usage_change_percent):
        """
        Sets the usage_change_percent of this ResourceUsageSummary.
        Change in resource utilization in percentage


        :param usage_change_percent: The usage_change_percent of this ResourceUsageSummary.
        :type: float
        """
        self._usage_change_percent = usage_change_percent

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ResourceRiskScoreAggregation(object):
    """
    Risk score of a resource.
    """

    #: A constant which can be used with the risk_level property of a ResourceRiskScoreAggregation.
    #: This constant has a value of "CRITICAL"
    RISK_LEVEL_CRITICAL = "CRITICAL"

    #: A constant which can be used with the risk_level property of a ResourceRiskScoreAggregation.
    #: This constant has a value of "HIGH"
    RISK_LEVEL_HIGH = "HIGH"

    #: A constant which can be used with the risk_level property of a ResourceRiskScoreAggregation.
    #: This constant has a value of "MEDIUM"
    RISK_LEVEL_MEDIUM = "MEDIUM"

    #: A constant which can be used with the risk_level property of a ResourceRiskScoreAggregation.
    #: This constant has a value of "LOW"
    RISK_LEVEL_LOW = "LOW"

    #: A constant which can be used with the risk_level property of a ResourceRiskScoreAggregation.
    #: This constant has a value of "MINOR"
    RISK_LEVEL_MINOR = "MINOR"

    def __init__(self, **kwargs):
        """
        Initializes a new ResourceRiskScoreAggregation object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param tactics:
            The value to assign to the tactics property of this ResourceRiskScoreAggregation.
        :type tactics: list[str]

        :param score_timestamp:
            The value to assign to the score_timestamp property of this ResourceRiskScoreAggregation.
        :type score_timestamp: float

        :param risk_score:
            The value to assign to the risk_score property of this ResourceRiskScoreAggregation.
        :type risk_score: float

        :param risk_level:
            The value to assign to the risk_level property of this ResourceRiskScoreAggregation.
            Allowed values for this property are: "CRITICAL", "HIGH", "MEDIUM", "LOW", "MINOR", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type risk_level: str

        """
        self.swagger_types = {
            'tactics': 'list[str]',
            'score_timestamp': 'float',
            'risk_score': 'float',
            'risk_level': 'str'
        }

        self.attribute_map = {
            'tactics': 'tactics',
            'score_timestamp': 'scoreTimestamp',
            'risk_score': 'riskScore',
            'risk_level': 'riskLevel'
        }

        self._tactics = None
        self._score_timestamp = None
        self._risk_score = None
        self._risk_level = None

    @property
    def tactics(self):
        """
        **[Required]** Gets the tactics of this ResourceRiskScoreAggregation.
        Tactics used for evaluating the risk scrore


        :return: The tactics of this ResourceRiskScoreAggregation.
        :rtype: list[str]
        """
        return self._tactics

    @tactics.setter
    def tactics(self, tactics):
        """
        Sets the tactics of this ResourceRiskScoreAggregation.
        Tactics used for evaluating the risk scrore


        :param tactics: The tactics of this ResourceRiskScoreAggregation.
        :type: list[str]
        """
        self._tactics = tactics

    @property
    def score_timestamp(self):
        """
        **[Required]** Gets the score_timestamp of this ResourceRiskScoreAggregation.
        The date and time for which the score is calculated. Format defined by RFC3339.


        :return: The score_timestamp of this ResourceRiskScoreAggregation.
        :rtype: float
        """
        return self._score_timestamp

    @score_timestamp.setter
    def score_timestamp(self, score_timestamp):
        """
        Sets the score_timestamp of this ResourceRiskScoreAggregation.
        The date and time for which the score is calculated. Format defined by RFC3339.


        :param score_timestamp: The score_timestamp of this ResourceRiskScoreAggregation.
        :type: float
        """
        self._score_timestamp = score_timestamp

    @property
    def risk_score(self):
        """
        **[Required]** Gets the risk_score of this ResourceRiskScoreAggregation.
        Risk Score


        :return: The risk_score of this ResourceRiskScoreAggregation.
        :rtype: float
        """
        return self._risk_score

    @risk_score.setter
    def risk_score(self, risk_score):
        """
        Sets the risk_score of this ResourceRiskScoreAggregation.
        Risk Score


        :param risk_score: The risk_score of this ResourceRiskScoreAggregation.
        :type: float
        """
        self._risk_score = risk_score

    @property
    def risk_level(self):
        """
        **[Required]** Gets the risk_level of this ResourceRiskScoreAggregation.
        The Risk Level

        Allowed values for this property are: "CRITICAL", "HIGH", "MEDIUM", "LOW", "MINOR", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The risk_level of this ResourceRiskScoreAggregation.
        :rtype: str
        """
        return self._risk_level

    @risk_level.setter
    def risk_level(self, risk_level):
        """
        Sets the risk_level of this ResourceRiskScoreAggregation.
        The Risk Level


        :param risk_level: The risk_level of this ResourceRiskScoreAggregation.
        :type: str
        """
        allowed_values = ["CRITICAL", "HIGH", "MEDIUM", "LOW", "MINOR"]
        if not value_allowed_none_or_none_sentinel(risk_level, allowed_values):
            risk_level = 'UNKNOWN_ENUM_VALUE'
        self._risk_level = risk_level

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ServiceEnvironmentEndPointOverview(object):
    """
    An overview of service environment endpoints.
    """

    #: A constant which can be used with the environment_type property of a ServiceEnvironmentEndPointOverview.
    #: This constant has a value of "INSTANCE_URL_PROD"
    ENVIRONMENT_TYPE_INSTANCE_URL_PROD = "INSTANCE_URL_PROD"

    #: A constant which can be used with the environment_type property of a ServiceEnvironmentEndPointOverview.
    #: This constant has a value of "INSTANCE_URL_TEST"
    ENVIRONMENT_TYPE_INSTANCE_URL_TEST = "INSTANCE_URL_TEST"

    #: A constant which can be used with the environment_type property of a ServiceEnvironmentEndPointOverview.
    #: This constant has a value of "INSTANCE_URL_DEV"
    ENVIRONMENT_TYPE_INSTANCE_URL_DEV = "INSTANCE_URL_DEV"

    #: A constant which can be used with the environment_type property of a ServiceEnvironmentEndPointOverview.
    #: This constant has a value of "OTHER"
    ENVIRONMENT_TYPE_OTHER = "OTHER"

    def __init__(self, **kwargs):
        """
        Initializes a new ServiceEnvironmentEndPointOverview object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param environment_type:
            The value to assign to the environment_type property of this ServiceEnvironmentEndPointOverview.
            Allowed values for this property are: "INSTANCE_URL_PROD", "INSTANCE_URL_TEST", "INSTANCE_URL_DEV", "OTHER", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type environment_type: str

        :param url:
            The value to assign to the url property of this ServiceEnvironmentEndPointOverview.
        :type url: str

        :param description:
            The value to assign to the description property of this ServiceEnvironmentEndPointOverview.
        :type description: str

        """
        self.swagger_types = {
            'environment_type': 'str',
            'url': 'str',
            'description': 'str'
        }

        self.attribute_map = {
            'environment_type': 'environmentType',
            'url': 'url',
            'description': 'description'
        }

        self._environment_type = None
        self._url = None
        self._description = None

    @property
    def environment_type(self):
        """
        **[Required]** Gets the environment_type of this ServiceEnvironmentEndPointOverview.
        Service environment endpoint type.

        Allowed values for this property are: "INSTANCE_URL_PROD", "INSTANCE_URL_TEST", "INSTANCE_URL_DEV", "OTHER", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The environment_type of this ServiceEnvironmentEndPointOverview.
        :rtype: str
        """
        return self._environment_type

    @environment_type.setter
    def environment_type(self, environment_type):
        """
        Sets the environment_type of this ServiceEnvironmentEndPointOverview.
        Service environment endpoint type.


        :param environment_type: The environment_type of this ServiceEnvironmentEndPointOverview.
        :type: str
        """
        allowed_values = ["INSTANCE_URL_PROD", "INSTANCE_URL_TEST", "INSTANCE_URL_DEV", "OTHER"]
        if not value_allowed_none_or_none_sentinel(environment_type, allowed_values):
            environment_type = 'UNKNOWN_ENUM_VALUE'
        self._environment_type = environment_type

    @property
    def url(self):
        """
        **[Required]** Gets the url of this ServiceEnvironmentEndPointOverview.
        Service environment instance URL.


        :return: The url of this ServiceEnvironmentEndPointOverview.
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """
        Sets the url of this ServiceEnvironmentEndPointOverview.
        Service environment instance URL.


        :param url: The url of this ServiceEnvironmentEndPointOverview.
        :type: str
        """
        self._url = url

    @property
    def description(self):
        """
        Gets the description of this ServiceEnvironmentEndPointOverview.
        Description of the environment link


        :return: The description of this ServiceEnvironmentEndPointOverview.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ServiceEnvironmentEndPointOverview.
        Description of the environment link


        :param description: The description of this ServiceEnvironmentEndPointOverview.
        :type: str
        """
        self._description = description

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class OpsiDataObject(object):
    """
    OPSI data object.
    """

    #: A constant which can be used with the data_object_type property of a OpsiDataObject.
    #: This constant has a value of "DATABASE_INSIGHTS_DATA_OBJECT"
    DATA_OBJECT_TYPE_DATABASE_INSIGHTS_DATA_OBJECT = "DATABASE_INSIGHTS_DATA_OBJECT"

    #: A constant which can be used with the data_object_type property of a OpsiDataObject.
    #: This constant has a value of "HOST_INSIGHTS_DATA_OBJECT"
    DATA_OBJECT_TYPE_HOST_INSIGHTS_DATA_OBJECT = "HOST_INSIGHTS_DATA_OBJECT"

    #: A constant which can be used with the data_object_type property of a OpsiDataObject.
    #: This constant has a value of "EXADATA_INSIGHTS_DATA_OBJECT"
    DATA_OBJECT_TYPE_EXADATA_INSIGHTS_DATA_OBJECT = "EXADATA_INSIGHTS_DATA_OBJECT"

    def __init__(self, **kwargs):
        """
        Initializes a new OpsiDataObject object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.opsi.models.HostInsightsDataObject`
        * :class:`~oci.opsi.models.ExadataInsightsDataObject`
        * :class:`~oci.opsi.models.DatabaseInsightsDataObject`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param identifier:
            The value to assign to the identifier property of this OpsiDataObject.
        :type identifier: str

        :param data_object_type:
            The value to assign to the data_object_type property of this OpsiDataObject.
            Allowed values for this property are: "DATABASE_INSIGHTS_DATA_OBJECT", "HOST_INSIGHTS_DATA_OBJECT", "EXADATA_INSIGHTS_DATA_OBJECT", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type data_object_type: str

        :param display_name:
            The value to assign to the display_name property of this OpsiDataObject.
        :type display_name: str

        :param description:
            The value to assign to the description property of this OpsiDataObject.
        :type description: str

        :param columns_metadata:
            The value to assign to the columns_metadata property of this OpsiDataObject.
        :type columns_metadata: list[oci.opsi.models.DataObjectColumnMetadata]

        """
        self.swagger_types = {
            'identifier': 'str',
            'data_object_type': 'str',
            'display_name': 'str',
            'description': 'str',
            'columns_metadata': 'list[DataObjectColumnMetadata]'
        }

        self.attribute_map = {
            'identifier': 'identifier',
            'data_object_type': 'dataObjectType',
            'display_name': 'displayName',
            'description': 'description',
            'columns_metadata': 'columnsMetadata'
        }

        self._identifier = None
        self._data_object_type = None
        self._display_name = None
        self._description = None
        self._columns_metadata = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['dataObjectType']

        if type == 'HOST_INSIGHTS_DATA_OBJECT':
            return 'HostInsightsDataObject'

        if type == 'EXADATA_INSIGHTS_DATA_OBJECT':
            return 'ExadataInsightsDataObject'

        if type == 'DATABASE_INSIGHTS_DATA_OBJECT':
            return 'DatabaseInsightsDataObject'
        else:
            return 'OpsiDataObject'

    @property
    def identifier(self):
        """
        **[Required]** Gets the identifier of this OpsiDataObject.
        Unique identifier of OPSI data object.


        :return: The identifier of this OpsiDataObject.
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """
        Sets the identifier of this OpsiDataObject.
        Unique identifier of OPSI data object.


        :param identifier: The identifier of this OpsiDataObject.
        :type: str
        """
        self._identifier = identifier

    @property
    def data_object_type(self):
        """
        **[Required]** Gets the data_object_type of this OpsiDataObject.
        Type of OPSI data object.

        Allowed values for this property are: "DATABASE_INSIGHTS_DATA_OBJECT", "HOST_INSIGHTS_DATA_OBJECT", "EXADATA_INSIGHTS_DATA_OBJECT", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The data_object_type of this OpsiDataObject.
        :rtype: str
        """
        return self._data_object_type

    @data_object_type.setter
    def data_object_type(self, data_object_type):
        """
        Sets the data_object_type of this OpsiDataObject.
        Type of OPSI data object.


        :param data_object_type: The data_object_type of this OpsiDataObject.
        :type: str
        """
        allowed_values = ["DATABASE_INSIGHTS_DATA_OBJECT", "HOST_INSIGHTS_DATA_OBJECT", "EXADATA_INSIGHTS_DATA_OBJECT"]
        if not value_allowed_none_or_none_sentinel(data_object_type, allowed_values):
            data_object_type = 'UNKNOWN_ENUM_VALUE'
        self._data_object_type = data_object_type

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this OpsiDataObject.
        User-friendly name of OPSI data object.


        :return: The display_name of this OpsiDataObject.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this OpsiDataObject.
        User-friendly name of OPSI data object.


        :param display_name: The display_name of this OpsiDataObject.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this OpsiDataObject.
        Description of OPSI data object.


        :return: The description of this OpsiDataObject.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this OpsiDataObject.
        Description of OPSI data object.


        :param description: The description of this OpsiDataObject.
        :type: str
        """
        self._description = description

    @property
    def columns_metadata(self):
        """
        **[Required]** Gets the columns_metadata of this OpsiDataObject.
        Metadata of columns in a data object.


        :return: The columns_metadata of this OpsiDataObject.
        :rtype: list[oci.opsi.models.DataObjectColumnMetadata]
        """
        return self._columns_metadata

    @columns_metadata.setter
    def columns_metadata(self, columns_metadata):
        """
        Sets the columns_metadata of this OpsiDataObject.
        Metadata of columns in a data object.


        :param columns_metadata: The columns_metadata of this OpsiDataObject.
        :type: list[oci.opsi.models.DataObjectColumnMetadata]
        """
        self._columns_metadata = columns_metadata

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .create_data_asset_details import CreateDataAssetDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateDataAssetFromAdwc(CreateDataAssetDetails):
    """
    Details for the Autonomous Data Warehouse data asset type.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateDataAssetFromAdwc object with values from keyword arguments. The default value of the :py:attr:`~oci.data_integration.models.CreateDataAssetFromAdwc.model_type` attribute
        of this class is ``ORACLE_ADWC_DATA_ASSET`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this CreateDataAssetFromAdwc.
            Allowed values for this property are: "ORACLE_DATA_ASSET", "ORACLE_OBJECT_STORAGE_DATA_ASSET", "ORACLE_ATP_DATA_ASSET", "ORACLE_ADWC_DATA_ASSET", "MYSQL_DATA_ASSET", "GENERIC_JDBC_DATA_ASSET", "FUSION_APP_DATA_ASSET", "AMAZON_S3_DATA_ASSET"
        :type model_type: str

        :param key:
            The value to assign to the key property of this CreateDataAssetFromAdwc.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this CreateDataAssetFromAdwc.
        :type model_version: str

        :param name:
            The value to assign to the name property of this CreateDataAssetFromAdwc.
        :type name: str

        :param description:
            The value to assign to the description property of this CreateDataAssetFromAdwc.
        :type description: str

        :param object_status:
            The value to assign to the object_status property of this CreateDataAssetFromAdwc.
        :type object_status: int

        :param identifier:
            The value to assign to the identifier property of this CreateDataAssetFromAdwc.
        :type identifier: str

        :param external_key:
            The value to assign to the external_key property of this CreateDataAssetFromAdwc.
        :type external_key: str

        :param asset_properties:
            The value to assign to the asset_properties property of this CreateDataAssetFromAdwc.
        :type asset_properties: dict(str, str)

        :param registry_metadata:
            The value to assign to the registry_metadata property of this CreateDataAssetFromAdwc.
        :type registry_metadata: oci.data_integration.models.RegistryMetadata

        :param service_name:
            The value to assign to the service_name property of this CreateDataAssetFromAdwc.
        :type service_name: str

        :param driver_class:
            The value to assign to the driver_class property of this CreateDataAssetFromAdwc.
        :type driver_class: str

        :param credential_file_content:
            The value to assign to the credential_file_content property of this CreateDataAssetFromAdwc.
        :type credential_file_content: str

        :param wallet_secret:
            The value to assign to the wallet_secret property of this CreateDataAssetFromAdwc.
        :type wallet_secret: oci.data_integration.models.SensitiveAttribute

        :param wallet_password_secret:
            The value to assign to the wallet_password_secret property of this CreateDataAssetFromAdwc.
        :type wallet_password_secret: oci.data_integration.models.SensitiveAttribute

        :param region_id:
            The value to assign to the region_id property of this CreateDataAssetFromAdwc.
        :type region_id: str

        :param tenancy_id:
            The value to assign to the tenancy_id property of this CreateDataAssetFromAdwc.
        :type tenancy_id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateDataAssetFromAdwc.
        :type compartment_id: str

        :param autonomous_db_id:
            The value to assign to the autonomous_db_id property of this CreateDataAssetFromAdwc.
        :type autonomous_db_id: str

        :param default_connection:
            The value to assign to the default_connection property of this CreateDataAssetFromAdwc.
        :type default_connection: oci.data_integration.models.CreateConnectionFromAdwc

        """
        self.swagger_types = {
            'model_type': 'str',
            'key': 'str',
            'model_version': 'str',
            'name': 'str',
            'description': 'str',
            'object_status': 'int',
            'identifier': 'str',
            'external_key': 'str',
            'asset_properties': 'dict(str, str)',
            'registry_metadata': 'RegistryMetadata',
            'service_name': 'str',
            'driver_class': 'str',
            'credential_file_content': 'str',
            'wallet_secret': 'SensitiveAttribute',
            'wallet_password_secret': 'SensitiveAttribute',
            'region_id': 'str',
            'tenancy_id': 'str',
            'compartment_id': 'str',
            'autonomous_db_id': 'str',
            'default_connection': 'CreateConnectionFromAdwc'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'key': 'key',
            'model_version': 'modelVersion',
            'name': 'name',
            'description': 'description',
            'object_status': 'objectStatus',
            'identifier': 'identifier',
            'external_key': 'externalKey',
            'asset_properties': 'assetProperties',
            'registry_metadata': 'registryMetadata',
            'service_name': 'serviceName',
            'driver_class': 'driverClass',
            'credential_file_content': 'credentialFileContent',
            'wallet_secret': 'walletSecret',
            'wallet_password_secret': 'walletPasswordSecret',
            'region_id': 'regionId',
            'tenancy_id': 'tenancyId',
            'compartment_id': 'compartmentId',
            'autonomous_db_id': 'autonomousDbId',
            'default_connection': 'defaultConnection'
        }

        self._model_type = None
        self._key = None
        self._model_version = None
        self._name = None
        self._description = None
        self._object_status = None
        self._identifier = None
        self._external_key = None
        self._asset_properties = None
        self._registry_metadata = None
        self._service_name = None
        self._driver_class = None
        self._credential_file_content = None
        self._wallet_secret = None
        self._wallet_password_secret = None
        self._region_id = None
        self._tenancy_id = None
        self._compartment_id = None
        self._autonomous_db_id = None
        self._default_connection = None
        self._model_type = 'ORACLE_ADWC_DATA_ASSET'

    @property
    def service_name(self):
        """
        Gets the service_name of this CreateDataAssetFromAdwc.
        The Autonomous Data Warehouse instance service name.


        :return: The service_name of this CreateDataAssetFromAdwc.
        :rtype: str
        """
        return self._service_name

    @service_name.setter
    def service_name(self, service_name):
        """
        Sets the service_name of this CreateDataAssetFromAdwc.
        The Autonomous Data Warehouse instance service name.


        :param service_name: The service_name of this CreateDataAssetFromAdwc.
        :type: str
        """
        self._service_name = service_name

    @property
    def driver_class(self):
        """
        Gets the driver_class of this CreateDataAssetFromAdwc.
        The Autonomous Data Warehouse driver class.


        :return: The driver_class of this CreateDataAssetFromAdwc.
        :rtype: str
        """
        return self._driver_class

    @driver_class.setter
    def driver_class(self, driver_class):
        """
        Sets the driver_class of this CreateDataAssetFromAdwc.
        The Autonomous Data Warehouse driver class.


        :param driver_class: The driver_class of this CreateDataAssetFromAdwc.
        :type: str
        """
        self._driver_class = driver_class

    @property
    def credential_file_content(self):
        """
        Gets the credential_file_content of this CreateDataAssetFromAdwc.
        The credential file content from a Autonomous Data Warehouse wallet.


        :return: The credential_file_content of this CreateDataAssetFromAdwc.
        :rtype: str
        """
        return self._credential_file_content

    @credential_file_content.setter
    def credential_file_content(self, credential_file_content):
        """
        Sets the credential_file_content of this CreateDataAssetFromAdwc.
        The credential file content from a Autonomous Data Warehouse wallet.


        :param credential_file_content: The credential_file_content of this CreateDataAssetFromAdwc.
        :type: str
        """
        self._credential_file_content = credential_file_content

    @property
    def wallet_secret(self):
        """
        Gets the wallet_secret of this CreateDataAssetFromAdwc.

        :return: The wallet_secret of this CreateDataAssetFromAdwc.
        :rtype: oci.data_integration.models.SensitiveAttribute
        """
        return self._wallet_secret

    @wallet_secret.setter
    def wallet_secret(self, wallet_secret):
        """
        Sets the wallet_secret of this CreateDataAssetFromAdwc.

        :param wallet_secret: The wallet_secret of this CreateDataAssetFromAdwc.
        :type: oci.data_integration.models.SensitiveAttribute
        """
        self._wallet_secret = wallet_secret

    @property
    def wallet_password_secret(self):
        """
        Gets the wallet_password_secret of this CreateDataAssetFromAdwc.

        :return: The wallet_password_secret of this CreateDataAssetFromAdwc.
        :rtype: oci.data_integration.models.SensitiveAttribute
        """
        return self._wallet_password_secret

    @wallet_password_secret.setter
    def wallet_password_secret(self, wallet_password_secret):
        """
        Sets the wallet_password_secret of this CreateDataAssetFromAdwc.

        :param wallet_password_secret: The wallet_password_secret of this CreateDataAssetFromAdwc.
        :type: oci.data_integration.models.SensitiveAttribute
        """
        self._wallet_password_secret = wallet_password_secret

    @property
    def region_id(self):
        """
        Gets the region_id of this CreateDataAssetFromAdwc.
        The Autonomous Data Warehouse instance region Id.


        :return: The region_id of this CreateDataAssetFromAdwc.
        :rtype: str
        """
        return self._region_id

    @region_id.setter
    def region_id(self, region_id):
        """
        Sets the region_id of this CreateDataAssetFromAdwc.
        The Autonomous Data Warehouse instance region Id.


        :param region_id: The region_id of this CreateDataAssetFromAdwc.
        :type: str
        """
        self._region_id = region_id

    @property
    def tenancy_id(self):
        """
        Gets the tenancy_id of this CreateDataAssetFromAdwc.
        The Autonomous Data Warehouse instance tenancy Id.


        :return: The tenancy_id of this CreateDataAssetFromAdwc.
        :rtype: str
        """
        return self._tenancy_id

    @tenancy_id.setter
    def tenancy_id(self, tenancy_id):
        """
        Sets the tenancy_id of this CreateDataAssetFromAdwc.
        The Autonomous Data Warehouse instance tenancy Id.


        :param tenancy_id: The tenancy_id of this CreateDataAssetFromAdwc.
        :type: str
        """
        self._tenancy_id = tenancy_id

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this CreateDataAssetFromAdwc.
        The Autonomous Data Warehouse instance compartment Id.


        :return: The compartment_id of this CreateDataAssetFromAdwc.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateDataAssetFromAdwc.
        The Autonomous Data Warehouse instance compartment Id.


        :param compartment_id: The compartment_id of this CreateDataAssetFromAdwc.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def autonomous_db_id(self):
        """
        Gets the autonomous_db_id of this CreateDataAssetFromAdwc.
        Tha Autonomous Database Id


        :return: The autonomous_db_id of this CreateDataAssetFromAdwc.
        :rtype: str
        """
        return self._autonomous_db_id

    @autonomous_db_id.setter
    def autonomous_db_id(self, autonomous_db_id):
        """
        Sets the autonomous_db_id of this CreateDataAssetFromAdwc.
        Tha Autonomous Database Id


        :param autonomous_db_id: The autonomous_db_id of this CreateDataAssetFromAdwc.
        :type: str
        """
        self._autonomous_db_id = autonomous_db_id

    @property
    def default_connection(self):
        """
        Gets the default_connection of this CreateDataAssetFromAdwc.

        :return: The default_connection of this CreateDataAssetFromAdwc.
        :rtype: oci.data_integration.models.CreateConnectionFromAdwc
        """
        return self._default_connection

    @default_connection.setter
    def default_connection(self, default_connection):
        """
        Sets the default_connection of this CreateDataAssetFromAdwc.

        :param default_connection: The default_connection of this CreateDataAssetFromAdwc.
        :type: oci.data_integration.models.CreateConnectionFromAdwc
        """
        self._default_connection = default_connection

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
